@@ -117,6 +117,8 @@ public:
 	void Update_Pot();
 	double Get_Potential(int *configuration);
 	double Get_LogPotential(int *configuration);
+	void Normalize_NodePot();
+	void Normalize_EdgePot();
 	void Normalize_NodeBel();
 	void Normalize_EdgeBel();
 	void UB_Init();
